[![CI](https://github.com/Zerwin/YoutubeMusicPython/actions/workflows/ci.yml/badge.svg)](https://github.com/Zerwin/YoutubeMusicPython/actions/workflows/ci.yml)

Python library wrapper around https://github.com/th-ch/youtube-music, mainly for use with Home Assistant.